import logging
from os import environ as env

import logstash


class TCPLogstashHandler(logstash.TCPLogstashHandler):
    def __init__(self, app_name, *args, **kwargs):
        self.app_name = app_name
        super(TCPLogstashHandler, self).__init__(*args, **kwargs)

    def makePickle(self, record):
        if self.app_name:
            record.app_name = self.app_name
        return super(TCPLogstashHandler, self).makePickle(record)


class UDPLogstashHandler(logstash.UDPLogstashHandler):
    def __init__(self, app_name, *args, **kwargs):
        self.app_name = app_name
        super(UDPLogstashHandler, self).__init__(*args, **kwargs)

    def makePickle(self, record):
        if self.app_name:
            record.app_name = self.app_name
        return super(UDPLogstashHandler, self).makePickle(record)


def init_logstash():
    proto_classes = dict(UDP=UDPLogstashHandler, TCP=TCPLogstashHandler)
    handler_class = proto_classes.get(env.get('LOGSTASH_PROTO', 'UDP'))
    if handler_class:
        root_logger = logging.getLogger()
        app_name = env.get('LOGSTASH_APP_NAME')
        tag = env.get('LOGSTASH_TAG')
        handler = handler_class(
            app_name=app_name,
            host=env.get('LOGSTASH_HOST', 'localhost'),
            port=int(env.get('LOGSTASH_PORT', 5000)),
            tags=[tag] if tag else None,
            version=1
        )
        root_logger.addHandler(handler)


def patch():
    original_basicConfig = logging.basicConfig

    def basicConfig(**kwargs):
        original_basicConfig(**kwargs)
        init_logstash()

    logging.basicConfig = basicConfig


patch()



#!/usr/bin/env python

from setuptools import setup

setup(
    name='logstash-easy',
    version='1.0',
    description='Very easy to use Logstash logging handler',
    long_description=open('README.rst').read(),
    platforms='all',
    license='MIT',
    author='Alexander Tikhonov',
    author_email='random.gauss@gmail.com',
    url='https://github.com/Fatal1ty/logstash-easy',
    classifiers=[
          'Development Status :: 5 - Production/Stable',
          'Environment :: Console',
          'License :: OSI Approved :: MIT License',
          'Natural Language :: English',
          'Operating System :: MacOS :: MacOS X',
          'Operating System :: POSIX',
          'Programming Language :: Python',
          'Programming Language :: Python :: 2',
          'Programming Language :: Python :: 2.7',
          'Programming Language :: Python :: 3',
          'Programming Language :: Python :: 3.4',
          'Programming Language :: Python :: 3.5',
          'Programming Language :: Python :: Implementation :: CPython',
          'Topic :: Software Development :: Libraries :: Python Modules',
          'Topic :: System',
          'Topic :: System :: Software Distribution',
          ],
    py_modules=['logstash_easy'],
    install_requires=[
        'python-logstash==0.4.6',
    ]
)
